==============================
Statistics with zfit
==============================

# TODO



.. density_estimation:

Advanced topics
================

.. toctree::
    :maxdepth: 2

    statistics/kernel_density_estimation
    statistics/numerical_integration
